@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2025 Valve Corporation
- * Copyright (c) 2020-2025 LunarG, Inc.
+ * Copyright (c) 2020-2026 Valve Corporation
+ * Copyright (c) 2020-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -126,17 +126,12 @@ bool Configuration::Load(const Path& full_path, const LayerManager& layers) {
         this->default_control = ::GetLayerControl(ReadString(json_configuration_object, "default_layer_control").c_str());
     }
 
-    if (json_configuration_object.value("override_layers") != QJsonValue::Undefined) {
-        this->override_layers = ReadBoolValue(json_configuration_object, "override_layers");
+    if (json_configuration_object.value("override_settings") != QJsonValue::Undefined) {
+        this->override_settings = ReadBoolValue(json_configuration_object, "override_settings");
     }
 
-    if (json_configuration_object.value("override_loader") != QJsonValue::Undefined) {
-        this->override_loader = ReadBoolValue(json_configuration_object, "override_loader");
-    }
-
-    if (json_configuration_object.value("loader_message_types") != QJsonValue::Undefined) {
-        const std::vector<std::string>& loader_messsage_types = ReadStringArray(json_configuration_object, "loader_message_types");
-        this->loader_log_messages_flags = GetLogFlags(loader_messsage_types);
+    if (json_configuration_object.value("override_settings_path") != QJsonValue::Undefined) {
+        this->override_settings_path = ReadString(json_configuration_object, "override_settings_path");
     }
 
     if (json_configuration_object.value("selected_layer_name") != QJsonValue::Undefined) {
@@ -300,9 +295,8 @@ bool Configuration::Save(const Path& full_path, bool export_mode) const {
     json_configuration.insert("version", this->version);
     SaveStringArray(json_configuration, "platforms", GetPlatformTokens(this->platform_flags));
     json_configuration.insert("default_layer_control", ::GetToken(this->default_control));
-    json_configuration.insert("override_layers", this->override_layers);
-    json_configuration.insert("override_loader", this->override_loader);
-    SaveStringArray(json_configuration, "loader_message_types", GetLogTokens(this->loader_log_messages_flags));
+    json_configuration.insert("override_settings", this->override_settings);
+    json_configuration.insert("override_settings_path", this->override_settings_path.RelativePath().c_str());
     json_configuration.insert("selected_layer_name", this->selected_layer_name.c_str());
     json_configuration.insert("layers", json_layers);
 
@@ -350,10 +344,6 @@ const Parameter* Configuration::Find(const std::string& layer_key) const {
 }
 
 Parameter* Configuration::GetActiveParameter() {
-    if (!this->override_layers) {
-        return nullptr;
-    }
-
     if (this->selected_layer_name.empty()) {
         return nullptr;
     }
@@ -573,20 +563,6 @@ void Configuration::Reorder(const std::vector<std::string>& layer_names) {
     this->parameters = ordered_parameters;
 }
 
-bool Configuration::HasMultipleActiveParameter() const {
-    std::size_t count = 0;
-
-    for (std::size_t i = 0, n = this->parameters.size(); i < n; ++i) {
-        const LayerControl control = this->parameters[i].control;
-
-        if (control == LAYER_CONTROL_ON || control == LAYER_CONTROL_OFF) {
-            ++count;
-        }
-    }
-
-    return count > 1;
-}
-
 bool Configuration::IsDefault() const {
     const std::vector<Path>& builtin_configuration_files = CollectFilePaths(":/configurations/");
     for (std::size_t i = 0, n = builtin_configuration_files.size(); i < n; ++i) {
