@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2021 Valve Corporation
- * Copyright (c) 2020-2021 LunarG, Inc.
+ * Copyright (c) 2020-2026 Valve Corporation
+ * Copyright (c) 2020-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,46 +19,23 @@
  */
 
 #include "header.h"
-#include "util.h"
 #include "json.h"
 
-#include <cassert>
-
-SettingView GetSettingView(const char* token) {
-    assert(token != nullptr);
-    assert(std::strcmp(token, "") != 0);
-
-    for (int i = SETTING_VIEW_FIRST; i <= SETTING_VIEW_LAST; ++i) {
-        const SettingView state = static_cast<SettingView>(i);
-        if (ToUpperCase(token) == GetToken(state)) return state;
-    }
-
-    assert(0);  // Unknown token
-    return static_cast<SettingView>(-1);
-}
-
-const char* GetToken(SettingView state) {
-    assert(state >= SETTING_VIEW_FIRST && state <= SETTING_VIEW_LAST);
-
-    static const char* table[] = {
-        "STANDARD",  // SETTING_VIEW_STANDARD
-        "ADVANCED",  // SETTING_VIEW_ADVANCED
-        "HIDDEN",    // SETTING_VIEW_HIDDEN
-    };
-    static_assert(std::size(table) == SETTING_VIEW_COUNT, "The tranlation table size doesn't match the enum number of elements");
-
-    return table[state];
-}
-
 void LoadMetaHeader(Header& header, const QJsonObject& json_object) {
     header.label = ReadStringValue(json_object, "label");
     header.description = ReadStringValue(json_object, "description");
+    if (json_object.value("detailed") != QJsonValue::Undefined) {
+        header.detailed = ReadStringValue(json_object, "detailed");
+    }
     if (json_object.value("url") != QJsonValue::Undefined) {
         header.url = Path(ReadStringValue(json_object, "url"), false);
     }
     if (json_object.value("status") != QJsonValue::Undefined) {
         header.status = GetStatusType(ReadStringValue(json_object, "status").c_str());
     }
+    if (json_object.value("deprecated_by_key") != QJsonValue::Undefined) {
+        header.deprecated_by_key = ReadStringValue(json_object, "deprecated_by_key");
+    }
     if (json_object.value("view") != QJsonValue::Undefined) {
         header.view = GetSettingView(ReadStringValue(json_object, "view").c_str());
     }
