@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2025 Valve Corporation
- * Copyright (c) 2020-2025 LunarG, Inc.
+ * Copyright (c) 2020-2026 Valve Corporation
+ * Copyright (c) 2020-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -72,7 +72,7 @@ enum { LAYER_LOAD_COUNT = LAYER_LOAD_LAST - LAYER_LOAD_FIRST + 1 };
 
 class Layer {
    public:
-    enum { NO_PRESET = -1 };
+    enum { NO_PRESET = -1, DEFAULT_PRESET = 0 };
 
     Layer();
     Layer(const std::string& key);
@@ -91,6 +91,10 @@ class Layer {
     void AddSettingData(SettingDataSet& data_set, const QJsonValue& json_setting_value);
 
     void AddSettingsSet(SettingMetaSet& meta_set, const SettingMeta* parent, const QJsonValue& json_settings_value);
+    void AddSettingsDependences(const QJsonValue& json_settings_value);
+    void AddSettingsMessages(const QJsonValue& json_settings_value);
+
+    void FillPresetSettings(SettingDataSet& setting_data, const std::vector<SettingMeta*>& settings) const;
 
    public:
     std::string key;
