@@ -20,10 +20,10 @@
 
 #pragma once
 
-#include "platform.h"
+#include "type_platform.h"
 #include "layer.h"
 
-#if VKC_PLATFORM == VKC_PLATFORM_WINDOWS
+#if VKC_ENV == VKC_ENV_WIN32
 
 #include <QString>
 
@@ -31,8 +31,10 @@
 
 void AppendRegistryEntriesForLayers(QString override_file, QString settings_file);
 
-void RemoveRegistryEntriesForLayers(QString override_file, QString settings_file);
+void RemoveRegistryEntriesForLayers();
 
-void LoadRegistryLayers(const QString &path, std::vector<Layer> &layers, LayerType type);
+std::vector<LayersPathInfo> LoadRegistrySystemLayers(const char* path);
 
-#endif  // VKC_PLATFORM == VKC_PLATFORM_WINDOWS
+std::vector<LayersPathInfo> LoadRegistrySoftwareLayers(const char* path, LayerType type);
+
+#endif  // VKC_ENV == VKC_ENV_WIN32
