@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2021 Valve Corporation
- * Copyright (c) 2020-2021 LunarG, Inc.
+ * Copyright (c) 2020-2026 Valve Corporation
+ * Copyright (c) 2020-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,6 +21,7 @@
 #pragma once
 
 #include "header.h"
+#include "message.h"
 
 #include <memory>
 #include <vector>
@@ -63,6 +64,10 @@ enum { SETTING_COUNT = SETTING_LAST - SETTING_FIRST + 1 };
 
 SettingType GetSettingType(const char* token);
 const char* GetToken(SettingType type);
+const char* GetLayerSettingTypeString(SettingType type);
+const char* GetCodeTypeString(SettingType type);
+bool IsString(SettingType type);
+bool IsArray(SettingType type);
 
 inline bool IsEnum(SettingType type) {
     assert(type >= SETTING_FIRST && type <= SETTING_LAST);
@@ -93,9 +98,11 @@ DependenceMode GetDependenceMode(const char* token);
 enum ExportMode {
     EXPORT_MODE_OVERRIDE = 0,
     EXPORT_MODE_DOC,
+    EXPORT_MODE_CPP_DECLARATION_VALUES,
+    EXPORT_MODE_CPP_DECLARATION_AND_INIT,
 
     EXPORT_MODE_FIRST = EXPORT_MODE_OVERRIDE,
-    EXPORT_MODE_LAST = EXPORT_MODE_DOC
+    EXPORT_MODE_LAST = EXPORT_MODE_CPP_DECLARATION_AND_INIT
 };
 
 enum { EXPORT_MODE_COUNT = EXPORT_MODE_LAST - EXPORT_MODE_FIRST + 1 };
@@ -126,10 +133,12 @@ struct SettingMeta : public Header {
     SettingMetaSet children;
     SettingDataSet dependence;
     DependenceMode dependence_mode;
+    std::vector<Message> messages;
+    const std::string layer_key;
 
    protected:
-    virtual bool Equal(const SettingMeta& other) const;
     Layer& layer;
+    virtual bool Equal(const SettingMeta& other) const;
 
     std::vector<SettingData*> instances;
 };
@@ -201,6 +210,10 @@ std::string GetSettingOverride(const SettingMeta& meta);
 
 SettingDependenceMode CheckDependence(const SettingMeta& meta, const SettingDataSet& data_set);
 
+typedef std::map<std::string, int> IgnoredMessages;
+
+void CheckMessage(IgnoredMessages& ignored_messages, const SettingMeta& meta, SettingDataSet& data_set);
+
 template <typename SETTING_DATA>
 inline SETTING_DATA* Instantiate(SettingMeta* meta) {
     SETTING_DATA* data = static_cast<SETTING_DATA*>(meta->Instantiate());
