@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2025 Valve Corporation
- * Copyright (c) 2020-2025 LunarG, Inc.
+ * Copyright (c) 2020-2026 Valve Corporation
+ * Copyright (c) 2020-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -45,7 +45,7 @@ std::string SettingMetaFilesystem::Export(ExportMode export_mode) const {
         case EXPORT_MODE_OVERRIDE:
             return this->default_value.AbsolutePath();
         case EXPORT_MODE_DOC:
-            return this->default_value.RelativePath();
+            return ::ConvertStandardSeparators(this->default_value.RelativePath());
     }
 }
 
@@ -101,12 +101,16 @@ std::string SettingDataFilesystem::Export(ExportMode export_mode) const {
         default:
             assert(0);
             return "";
+        case EXPORT_MODE_CPP_DECLARATION_AND_INIT: {
+            return format("std::string %s = \"%s\";\n", this->key.c_str(),
+                          ::ConvertStandardSeparators(this->value.RelativePath()).c_str());
+        }
         case EXPORT_MODE_OVERRIDE: {
             Path file(this->value);
-            return file.AbsolutePath();
+            return ::ConvertStandardSeparators(file.AbsolutePath());
         }
         case EXPORT_MODE_DOC:
-            return Path(this->value).RelativePath();
+            return ::ConvertStandardSeparators(Path(this->value).RelativePath());
     }
 }
 
