@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2025 Valve Corporation
- * Copyright (c) 2020-2025 LunarG, Inc.
+ * Copyright (c) 2020-2026 Valve Corporation
+ * Copyright (c) 2020-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -67,6 +67,7 @@ struct SettingDataEnum : public SettingDataString {
     SettingDataEnum(const SettingMetaEnum* meta);
 
     void Copy(const SettingData* data) override;
+    std::string Export(ExportMode export_mode) const override;
     void Reset() override;
 
     const SettingMetaEnum* meta;
@@ -99,6 +100,9 @@ struct SettingDataFlags : public SettingData {
     std::string Export(ExportMode export_mode) const override;
     void Reset() override;
 
+    void Append(const SettingDataFlags* data);
+    void Remove(const SettingDataFlags* data);
+
     std::vector<std::string> value;
     std::map<std::string, bool> expanded_flags;
 
