@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2025 Valve Corporation
- * Copyright (c) 2020-2025 LunarG, Inc.
+ * Copyright (c) 2020-2026 Valve Corporation
+ * Copyright (c) 2020-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -93,12 +93,14 @@ bool SettingDataString::Save(QJsonObject& json_setting) const {
 }
 
 std::string SettingDataString::Export(ExportMode export_mode) const {
-    (void)export_mode;
+    const std::string actual_value = this->IsValid() ? this->value : this->meta->default_value;
 
-    if (this->IsValid()) {
-        return this->value;
-    } else {
-        return this->meta->default_value;
+    switch (export_mode) {
+        default:
+            return actual_value;
+        case EXPORT_MODE_CPP_DECLARATION_AND_INIT: {
+            return format("std::string %s = \"%s\";\n", this->key.c_str(), actual_value.c_str());
+        }
     }
 }
 
