@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2025 Valve Corporation
- * Copyright (c) 2020-2025 LunarG, Inc.
+ * Copyright (c) 2020-2026 Valve Corporation
+ * Copyright (c) 2020-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -46,32 +46,31 @@ TEST(test_path, native_path) {
 }
 
 TEST(test_path, native_compare) {
-    static const Path table[] = {
-        "/vkconfig/test\\path/format/",
-        "/vkconfig/test\\path/format\\",
-        "/vkconfig\\test/path/format/",
-        "/vkconfig\\test/path\\format/",
-        "/vkconfig/test/path/format/",
-        "\\vkconfig\\test/path\\format\\",
-        "/vkconfig/test\\path/format",
-        "/vkconfig/test\\path/format",
-        "/vkconfig\\test/path/format",
-        "/vkconfig\\test/path\\format",
-        "/vkconfig/test/path/format",
-        "\\vkconfig\\test/path\\format",
+    static const Path table[] = {"/vkconfig/test\\path/format/",
+                                 "/vkconfig/test\\path/format\\",
+                                 "/vkconfig\\test/path/format/",
+                                 "/vkconfig\\test/path\\format/",
+                                 "/vkconfig/test/path/format/",
+                                 "\\vkconfig\\test/path\\format\\",
+                                 "/vkconfig/test\\path/format",
+                                 "/vkconfig/test\\path/format",
+                                 "/vkconfig\\test/path/format",
+                                 "/vkconfig\\test/path\\format",
+                                 "/vkconfig/test/path/format",
+                                 "\\vkconfig\\test/path\\format",
 #if (VKC_ENV == VKC_ENV_WIN32)  // Only on Windows the case doesn't matter for paths
-        "/vkConfig/test\\path/format/",
-        "/vkConfig/Test\\Path/Format\\",
-        "/vkconfig\\test/path/Format/",
-        "/vkConfig\\test/path\\format/",
-        "/vkConfig/Test/Path/Format/",
-        "\\vkconfig\\test/path\\Format\\",
-        "/vkConfig/test\\path/format",
-        "/vkConfig/Test\\Path/Format",
-        "/vkconfig\\test/path/Format",
-        "/vkConfig\\test/path\\format",
-        "/vkConfig/Test/Path/Format",
-        "\\vkconfig\\test/path\\Format"
+                                 "/vkConfig/test\\path/format/",
+                                 "/vkConfig/Test\\Path/Format\\",
+                                 "/vkconfig\\test/path/Format/",
+                                 "/vkConfig\\test/path\\format/",
+                                 "/vkConfig/Test/Path/Format/",
+                                 "\\vkconfig\\test/path\\Format\\",
+                                 "/vkConfig/test\\path/format",
+                                 "/vkConfig/Test\\Path/Format",
+                                 "/vkconfig\\test/path/Format",
+                                 "/vkConfig\\test/path\\format",
+                                 "/vkConfig/Test/Path/Format",
+                                 "\\vkconfig\\test/path\\Format"
 #endif
     };
 
@@ -352,17 +351,10 @@ TEST(test_path, get_path_url_sdk) {
     EXPECT_TRUE(value.find(expected) != std::string::npos);
 }
 
-TEST(test_path, collect_file_paths_success_set1) {
-    const std::vector<Path>& paths = CollectFilePaths(":/configurations/");
-
-    EXPECT_EQ(paths.size(), 8);
-    EXPECT_STREQ(Path(":/configurations/API dump.json").AbsolutePath().c_str(), paths[0].AbsolutePath().c_str());
-}
-
 TEST(test_path, collect_file_paths_success_set2) {
     const std::vector<Path>& paths = CollectFilePaths(":/layers/");
 
-    EXPECT_EQ(paths.size(), 16);
+    EXPECT_EQ(paths.size(), 17);
     EXPECT_STREQ(Path(":/layers/VK_LAYER_LUNARG_reference_1_1_0.json").AbsolutePath().c_str(), paths[0].AbsolutePath().c_str());
 }
 
