@@ -69,6 +69,7 @@ TEST(test_setting_type_file_save, value) {
 
     SettingDataFileSave* data = Instantiate<SettingDataFileSave>(meta);
     data->value = "${VULKAN_CONTENT}/value";
-    EXPECT_STREQ(Path("${VULKAN_CONTENT}/value").RelativePath().c_str(), data->Export(EXPORT_MODE_DOC).c_str());
+    EXPECT_STREQ(::ConvertStandardSeparators(Path("${VULKAN_CONTENT}/value").RelativePath()).c_str(),
+                 data->Export(EXPORT_MODE_DOC).c_str());
     EXPECT_STRNE(Path("${VULKAN_CONTENT}/value").RelativePath().c_str(), data->Export(EXPORT_MODE_OVERRIDE).c_str());
 }
