@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2025 Valve Corporation
- * Copyright (c) 2020-2025 LunarG, Inc.
+ * Copyright (c) 2020-2026 Valve Corporation
+ * Copyright (c) 2020-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@
 
 #include <gtest/gtest.h>
 
-#ifndef RUN_ON_GITHUB
+#ifndef RUN_ON_CI
 
 TEST(test_vulkan, system_info) {
     const VulkanSystemInfo& vulkan_system_info = BuildVulkanSystemInfo();
@@ -33,4 +33,4 @@ TEST(test_vulkan, system_info) {
     EXPECT_TRUE(!vulkan_system_info.physicalDevices.empty());
 }
 
-#endif  // RUN_ON_GITHUB
+#endif  // RUN_ON_CI
