@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2025 Valve Corporation
- * Copyright (c) 2020-2025 LunarG, Inc.
+ * Copyright (c) 2020-2026 Valve Corporation
+ * Copyright (c) 2020-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,4 +20,16 @@
 
 #pragma once
 
-enum ConfiguratorMode { CONFIGURATOR_MODE_NONE = 0, CONFIGURATOR_MODE_GUI, CONFIGURATOR_MODE_CMD };
+enum ConfiguratorMode {
+    CONFIGURATOR_MODE_NONE = 0,
+    CONFIGURATOR_MODE_GUI,
+    CONFIGURATOR_MODE_CMD,
+    CONFIGURATOR_MODE_DRY,
+
+    CONFIGURATOR_MODE_FIRST = CONFIGURATOR_MODE_NONE,
+    CONFIGURATOR_MODE_LAST = CONFIGURATOR_MODE_DRY,
+};
+
+enum { CONFIGURATOR_MODE_COUNT = CONFIGURATOR_MODE_LAST - CONFIGURATOR_MODE_FIRST + 1 };
+
+inline bool RequireLoading(ConfiguratorMode mode) { return mode == CONFIGURATOR_MODE_GUI || mode == CONFIGURATOR_MODE_CMD; }
