@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2025 Valve Corporation
- * Copyright (c) 2020-2025 LunarG, Inc.
+ * Copyright (c) 2020-2026 Valve Corporation
+ * Copyright (c) 2020-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -30,7 +30,7 @@
 #include <sstream>
 #include <iostream>
 
-static std::string GetUUIDString(const uint8_t deviceUUID[VK_UUID_SIZE]) {
+std::string GetUUIDString(const uint8_t deviceUUID[VK_UUID_SIZE]) {
     std::string result;
 
     for (std::size_t i = 0, n = VK_UUID_SIZE; i < n; ++i) {
@@ -40,7 +40,7 @@ static std::string GetUUIDString(const uint8_t deviceUUID[VK_UUID_SIZE]) {
     return result;
 }
 
-static std::string GetLUIDString(const uint8_t deviceLUID[VK_LUID_SIZE]) {
+std::string GetLUIDString(const uint8_t deviceLUID[VK_LUID_SIZE]) {
     std::string result;
 
     for (std::size_t i = 0, n = VK_LUID_SIZE; i < n; ++i) {
@@ -100,7 +100,7 @@ bool VulkanFunctions::Validate() const {
            this->CreateInstance != nullptr && this->DestroyInstance != nullptr && this->GetPhysicalDeviceProperties2 != nullptr;
 }
 
-static VkResult CreateInstance(const VulkanFunctions &vk, bool enumerate_portability, VkInstance &instance) {
+static VkResult CreateInstance(const VulkanFunctions &vk, VkInstance &instance) {
     uint32_t property_count = 0;
     VkResult err = vk.EnumerateInstanceExtensionProperties(nullptr, &property_count, nullptr);
     assert(err == VK_SUCCESS);
@@ -112,17 +112,16 @@ static VkResult CreateInstance(const VulkanFunctions &vk, bool enumerate_portabi
     // Handle Portability Enumeration requirements
     std::vector<const char *> instance_extensions;
 
+    bool enumerate_portability = false;
     for (std::size_t i = 0, n = instance_properties.size(); i < n; ++i) {
         if (instance_properties[i].extensionName == std::string(VK_KHR_EXTERNAL_MEMORY_CAPABILITIES_EXTENSION_NAME)) {
             instance_extensions.push_back(VK_KHR_EXTERNAL_MEMORY_CAPABILITIES_EXTENSION_NAME);
         }
-#if VK_KHR_portability_enumeration
-        if (enumerate_portability) {
-            if (instance_properties[i].extensionName == std::string(VK_KHR_PORTABILITY_ENUMERATION_EXTENSION_NAME)) {
-                instance_extensions.push_back(VK_KHR_PORTABILITY_ENUMERATION_EXTENSION_NAME);
-            }
+
+        if (instance_properties[i].extensionName == std::string(VK_KHR_PORTABILITY_ENUMERATION_EXTENSION_NAME)) {
+            instance_extensions.push_back(VK_KHR_PORTABILITY_ENUMERATION_EXTENSION_NAME);
+            enumerate_portability = true;
         }
-#endif
     }
 
     // Check Vulkan Devices
@@ -138,11 +137,11 @@ static VkResult CreateInstance(const VulkanFunctions &vk, bool enumerate_portabi
 
     VkInstanceCreateInfo inst_info = {};
     inst_info.sType = VK_STRUCTURE_TYPE_INSTANCE_CREATE_INFO;
-#if VK_KHR_portability_enumeration
+
     if (enumerate_portability) {
         inst_info.flags = VK_INSTANCE_CREATE_ENUMERATE_PORTABILITY_BIT_KHR;
     }
-#endif
+
     inst_info.pNext = nullptr;
     inst_info.pApplicationInfo = &app;
     inst_info.enabledLayerCount = 0;
@@ -153,6 +152,69 @@ static VkResult CreateInstance(const VulkanFunctions &vk, bool enumerate_portabi
     return vk.CreateInstance(&inst_info, nullptr, &instance);
 }
 
+std::string DeviceInfo::GetLabel() const {
+    if (this->driverName.empty()) {
+        return this->deviceName;
+    }
+
+    if (this->deviceName.find(this->driverName) != std::string::npos) {
+        return this->deviceName;
+    }
+
+    return this->driverName + " " + this->deviceName;
+}
+
+std::string VulkanPhysicalDeviceInfo::GetLabel() const {
+    if (this->driverName.empty()) {
+        return this->deviceName;
+    }
+
+    if (this->deviceName.find(this->driverName) != std::string::npos) {
+        return this->deviceName;
+    }
+
+    return this->driverName + " " + this->deviceName;
+}
+
+std::string VulkanPhysicalDeviceInfo::GetVersion() const {
+    if (this->vendorID == 0x10DE) {
+        return FormatNvidia(this->driverVersion);
+    } else if ((this->vendorID == 0x8086) && (VKC_PLATFORM & PLATFORM_WINDOWS_BIT)) {
+        return FormatIntelWindows(this->driverVersion);
+    } else {
+        return Version(this->driverVersion).str();
+    }
+}
+
+DeviceInfo GetDeviceInfo(const VulkanPhysicalDeviceInfo &info) {
+    DeviceInfo device_info;
+    device_info.deviceName = info.deviceName;
+    std::copy(std::begin(info.deviceUUID), std::end(info.deviceUUID), std::begin(device_info.deviceUUID));
+    device_info.driverName = info.driverName;
+    device_info.driverVersion = info.driverVersion;
+    return device_info;
+}
+
+bool operator==(const DeviceInfo &a, const DeviceInfo &b) {
+    if (a.deviceName != b.deviceName) {
+        return false;
+    }
+
+    for (int i = 0, n = VK_UUID_SIZE; i < n; ++i) {
+        if (a.deviceUUID[i] != b.deviceUUID[i]) {
+            return false;
+        }
+    }
+
+    if (a.driverVersion != b.driverVersion) {
+        return false;
+    }
+
+    return true;
+}
+
+bool operator!=(const DeviceInfo &a, const DeviceInfo &b) { return !(a == b); }
+
 VulkanSystemInfo BuildVulkanSystemInfo() {
     VulkanSystemInfo vulkan_system_info;
 
@@ -169,17 +231,21 @@ VulkanSystemInfo BuildVulkanSystemInfo() {
     std::uint32_t instance_layer_count = 0;
     result = vk.EnumerateInstanceLayerProperties(&instance_layer_count, nullptr);
     assert(result == VK_SUCCESS);
-    vulkan_system_info.instanceLayerProperties.resize(instance_layer_count);
-    result = vk.EnumerateInstanceLayerProperties(&instance_layer_count, vulkan_system_info.instanceLayerProperties.data());
-    assert(result == VK_SUCCESS);
+    if (instance_layer_count > 0) {
+        vulkan_system_info.instanceLayerProperties.resize(instance_layer_count);
+        result = vk.EnumerateInstanceLayerProperties(&instance_layer_count, vulkan_system_info.instanceLayerProperties.data());
+        assert(result == VK_SUCCESS);
+    }
 
     uint32_t instance_extension_count = 0;
     result = vk.EnumerateInstanceExtensionProperties(nullptr, &instance_extension_count, nullptr);
     assert(result == VK_SUCCESS);
-    vulkan_system_info.instanceExtensionPropertie.resize(instance_extension_count);
-    result = vk.EnumerateInstanceExtensionProperties(nullptr, &instance_extension_count,
-                                                     vulkan_system_info.instanceExtensionPropertie.data());
-    assert(result == VK_SUCCESS);
+    if (instance_extension_count > 0) {
+        vulkan_system_info.instanceExtensionPropertie.resize(instance_extension_count);
+        result = vk.EnumerateInstanceExtensionProperties(nullptr, &instance_extension_count,
+                                                         vulkan_system_info.instanceExtensionPropertie.data());
+        assert(result == VK_SUCCESS);
+    }
 
     // Handle Portability Enumeration requirements
     std::vector<const char *> instance_extensions;
@@ -237,20 +303,30 @@ VulkanSystemInfo BuildVulkanSystemInfo() {
     for (std::size_t i = 0, n = devices.size(); i < n; ++i) {
         VulkanPhysicalDeviceInfo &device_info = vulkan_system_info.physicalDevices[i];
 
-        VkPhysicalDeviceIDPropertiesKHR properties_deviceid{VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_ID_PROPERTIES_KHR, nullptr};
+        VkPhysicalDeviceDriverPropertiesKHR properties_driver{VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_DRIVER_PROPERTIES_KHR, nullptr};
+        VkPhysicalDeviceIDPropertiesKHR properties_deviceid{VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_ID_PROPERTIES_KHR,
+                                                            &properties_driver};
         VkPhysicalDeviceProperties2 properties2{VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_PROPERTIES_2, &properties_deviceid};
 
         vk.GetPhysicalDeviceProperties2(devices[i], &properties2);
 
         device_info.deviceName = properties2.properties.deviceName;
-        device_info.apiVersion = Version(properties2.properties.apiVersion);
+        device_info.driverName = properties_driver.driverName;
+
+        /* For multiple driver version testing only
+                if (device_info.deviceName.find("llvmpipe") != std::string::npos) {
+                    device_info.deviceName = "llvmpipe";
+                }
+        */
+
         device_info.driverVersion = properties2.properties.driverVersion;
+        device_info.apiVersion = Version(properties2.properties.apiVersion);
         device_info.vendorID = static_cast<VendorID>(properties2.properties.vendorID);
         device_info.deviceID = properties2.properties.deviceID;
         device_info.deviceType = properties2.properties.deviceType;
-        device_info.deviceUUID = GetUUIDString(properties_deviceid.deviceUUID);
-        device_info.driverUUID = GetUUIDString(properties_deviceid.driverUUID);
-        device_info.deviceLUID = GetLUIDString(properties_deviceid.deviceLUID);
+        memcpy(device_info.deviceUUID, properties_deviceid.deviceUUID, sizeof(device_info.deviceUUID));
+        memcpy(device_info.driverUUID, properties_deviceid.driverUUID, sizeof(device_info.driverUUID));
+        memcpy(device_info.deviceLUID, properties_deviceid.deviceLUID, sizeof(device_info.deviceLUID));
     }
 
     vk.DestroyInstance(instance, NULL);
@@ -366,6 +442,23 @@ std::vector<std::string> BuildEnvVariablesList(const char *layer_key, const char
     return results;
 }
 
+std::string GetCodeType(const std::string &layer_key) {
+    std::string key = TrimVendor(layer_key);
+    key.erase(std::remove_if(key.begin(), key.end(), [](char c) { return c == '_'; }), key.end());
+    key[0] = std::toupper(key[0]);
+    return key + "SettingData";
+}
+
+std::string GetCodeData(const std::string &layer_key) { return TrimVendor(layer_key); }
+
+std::string GetSettingValueName(const std::string &layer_key, const std::string &setting_key, const std::string &value_key) {
+    std::string layer = ::ToUpperCase(::GetCodeData(layer_key));
+    std::string setting = ::ToUpperCase(setting_key);
+    std::string value = ::ToUpperCase(value_key);
+
+    return format("VL_%s_%s_%s", layer.c_str(), setting.c_str(), value.c_str());
+}
+
 const char *GetLabel(VkPhysicalDeviceType deviceType) {
     static const char *TABLES[] = {
         "",            // VK_PHYSICAL_DEVICE_TYPE_OTHER
@@ -402,6 +495,8 @@ std::string GetLabel(VendorID vendorID) {
             return "Nvidia";
         case VENDOR_ID_QUALCOMM:
             return "Qualcomm";
+        case VENDOR_ID_HUAWEI:
+            return "Huawei";
     }
 }
 
@@ -422,12 +517,9 @@ std::string GenerateLoaderLog() {
     if (vk.Validate()) {
         VkInstance instance = VK_NULL_HANDLE;
 
-        VkResult err = ::CreateInstance(vk, false, instance);
+        VkResult err = ::CreateInstance(vk, instance);
         if (err == VK_ERROR_INCOMPATIBLE_DRIVER) {
-            err = ::CreateInstance(vk, true, instance);
-            if (err == VK_ERROR_INCOMPATIBLE_DRIVER) {
-                return "VK_ERROR_INCOMPATIBLE_DRIVER\n";
-            }
+            return "VK_ERROR_INCOMPATIBLE_DRIVER\n";
         }
         vk.DestroyInstance(instance, nullptr);
     }
