@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2020-2025 Valve Corporation
- * Copyright (c) 2020-2025 LunarG, Inc.
+ * Copyright (c) 2020-2026 Valve Corporation
+ * Copyright (c) 2020-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -32,14 +32,12 @@
 #include "widget_setting_string.h"
 #include "widget_setting_flags.h"
 #include "widget_setting_filesystem.h"
-#include "widget_setting_list_element.h"
 #include "widget_setting_list.h"
 
 #include "../vkconfig_core/configurator.h"
 #include "../vkconfig_core/version.h"
 #include "../vkconfig_core/util.h"
 #include "../vkconfig_core/type_platform.h"
-#include "../vkconfig_core/type_hide_message.h"
 
 #include <QLineEdit>
 #include <QPushButton>
@@ -88,10 +86,13 @@ void SettingsTreeManager::CreateGUI() {
     this->ui->configurations_group_box_settings->blockSignals(true);
     this->ui->configurations_group_box_settings->setTitle(format("%s:", title.c_str()).c_str());
     this->ui->configurations_group_box_settings->setEnabled(configurator.HasEnabledUI(ENABLE_UI_SETTINGS));
-    this->ui->configurations_group_box_settings->setCheckable(true);
+    this->ui->configurations_group_box_settings->setCheckable(!configurator.GetActiveConfiguration()->override_settings);
     this->ui->configurations_group_box_settings->setChecked(parameter->override_settings);
     this->ui->configurations_group_box_settings->blockSignals(false);
     this->ui->configurations_presets->setVisible(!layer->presets.empty());
+    this->ui->configurations_presets->setEnabled(!configurator.GetActiveConfiguration()->override_settings);
+    this->ui->configurations_settings->setEnabled(!configurator.GetActiveConfiguration()->override_settings);
+    this->ui->configurations_settings_reset->setVisible(!layer->presets.empty());
 
     const std::vector<Path> &layer_versions = configurator.layers.GatherManifests(parameter->key);
     this->ui->configurations_versions->setEnabled(true);
@@ -155,7 +156,7 @@ void SettingsTreeManager::CreateGUI() {
                 if (!IsPlatformSupported(layer_preset.platform_flags)) {
                     continue;
                 }
-                if (configurator.GetUseLayerDevMode()) {
+                if (configurator.GetUseLayerDebugMode()) {
                     if (layer_preset.view == SETTING_VIEW_HIDDEN) {
                         continue;
                     }
@@ -169,11 +170,14 @@ void SettingsTreeManager::CreateGUI() {
             }
 
             this->connect(this->ui->configurations_presets, SIGNAL(currentIndexChanged(int)), this, SLOT(OnPresetChanged(int)));
+            this->connect(this->ui->configurations_settings_reset, SIGNAL(clicked()), this, SLOT(OnSettingsResetted()));
             this->ui->configurations_presets->setVisible(true);
+            this->ui->configurations_settings_reset->setVisible(true);
 
             this->RefreshPresetLabel();
         } else {
             this->ui->configurations_presets->setVisible(false);
+            this->ui->configurations_settings_reset->setVisible(false);
         }
         this->ui->configurations_presets->blockSignals(false);
     }
@@ -206,6 +210,8 @@ void SettingsTreeManager::CleanupGUI() {
         this->ui->configurations_group_box_settings->setCheckable(false);
         this->ui->configurations_presets->setVisible(false);
         this->ui->configurations_versions->setVisible(false);
+        this->ui->configurations_presets->setVisible(false);
+        this->ui->configurations_settings_reset->setVisible(false);
         return;
     }
 
@@ -214,6 +220,8 @@ void SettingsTreeManager::CleanupGUI() {
         this->ui->configurations_group_box_settings->setCheckable(false);
         this->ui->configurations_presets->setVisible(false);
         this->ui->configurations_versions->setVisible(false);
+        this->ui->configurations_presets->setVisible(false);
+        this->ui->configurations_settings_reset->setVisible(false);
         return;
     }
 }
@@ -248,7 +256,7 @@ void SettingsTreeManager::BuildTreeItem(QTreeWidgetItem *parent, const SettingMe
     }
 
     Configurator &configurator = Configurator::Get();
-    if (configurator.GetUseLayerDevMode()) {
+    if (configurator.GetUseLayerDebugMode()) {
         if (meta_object.view == SETTING_VIEW_HIDDEN) {
             return;
         }
@@ -286,21 +294,21 @@ void SettingsTreeManager::BuildTreeItem(QTreeWidgetItem *parent, const SettingMe
             const SettingMetaBool &meta = static_cast<const SettingMetaBool &>(meta_object);
 
             WidgetSettingBool *widget = new WidgetSettingBool(this->ui->configurations_settings, item, meta, parameter->settings);
-            this->connect(widget, SIGNAL(itemChanged()), this, SLOT(OnSettingChanged()));
+            this->connect(widget, SIGNAL(refreshEnableOnly()), this, SLOT(OnRefreshEnableOnly()));
         } break;
 
         case SETTING_INT: {
             const SettingMetaInt &meta = static_cast<const SettingMetaInt &>(meta_object);
 
             WidgetSettingInt *widget = new WidgetSettingInt(this->ui->configurations_settings, item, meta, parameter->settings);
-            this->connect(widget, SIGNAL(itemChanged()), this, SLOT(OnSettingChanged()));
+            this->connect(widget, SIGNAL(refreshEnableOnly()), this, SLOT(OnRefreshEnableOnly()));
         } break;
 
         case SETTING_FLOAT: {
             const SettingMetaFloat &meta = static_cast<const SettingMetaFloat &>(meta_object);
 
             WidgetSettingFloat *widget = new WidgetSettingFloat(this->ui->configurations_settings, item, meta, parameter->settings);
-            this->connect(widget, SIGNAL(itemChanged()), this, SLOT(OnSettingChanged()));
+            this->connect(widget, SIGNAL(refreshEnableOnly()), this, SLOT(OnRefreshEnableOnly()));
         } break;
 
         case SETTING_FRAMES: {
@@ -308,7 +316,7 @@ void SettingsTreeManager::BuildTreeItem(QTreeWidgetItem *parent, const SettingMe
 
             WidgetSettingFrames *widget =
                 new WidgetSettingFrames(this->ui->configurations_settings, item, meta, parameter->settings);
-            this->connect(widget, SIGNAL(itemChanged()), this, SLOT(OnSettingChanged()));
+            this->connect(widget, SIGNAL(refreshEnableOnly()), this, SLOT(OnRefreshEnableOnly()));
         } break;
 
         case SETTING_SAVE_FILE:
@@ -319,7 +327,7 @@ void SettingsTreeManager::BuildTreeItem(QTreeWidgetItem *parent, const SettingMe
 
             WidgetSettingFilesystem *widget =
                 new WidgetSettingFilesystem(this->ui->configurations_settings, item, meta, parameter->settings);
-            this->connect(widget, SIGNAL(itemChanged()), this, SLOT(OnSettingChanged()));
+            this->connect(widget, SIGNAL(refreshEnableOnly()), this, SLOT(OnRefreshEnableOnly()));
         } break;
 
         case SETTING_ENUM: {
@@ -327,7 +335,7 @@ void SettingsTreeManager::BuildTreeItem(QTreeWidgetItem *parent, const SettingMe
 
             WidgetSettingEnum *enum_widget =
                 new WidgetSettingEnum(this->ui->configurations_settings, item, meta, parameter->settings);
-            this->connect(enum_widget, SIGNAL(itemChanged()), this, SLOT(OnSettingChanged()));
+            this->connect(enum_widget, SIGNAL(refreshEnableOnly()), this, SLOT(OnRefreshEnableOnly()));
 
             for (std::size_t i = 0, n = meta.enum_values.size(); i < n; ++i) {
                 const SettingEnumValue &value = meta.enum_values[i];
@@ -335,8 +343,15 @@ void SettingsTreeManager::BuildTreeItem(QTreeWidgetItem *parent, const SettingMe
                 if (!IsPlatformSupported(value.platform_flags)) {
                     continue;
                 }
-                if (value.view == SETTING_VIEW_HIDDEN) {
-                    continue;
+
+                if (configurator.GetUseLayerDebugMode()) {
+                    if (value.view == SETTING_VIEW_HIDDEN) {
+                        continue;
+                    }
+                } else {
+                    if (value.view != SETTING_VIEW_STANDARD) {
+                        continue;
+                    }
                 }
 
                 for (std::size_t i = 0, n = value.settings.size(); i < n; ++i) {
@@ -357,8 +372,15 @@ void SettingsTreeManager::BuildTreeItem(QTreeWidgetItem *parent, const SettingMe
                 if (!IsPlatformSupported(value.platform_flags)) {
                     continue;
                 }
-                if (value.view == SETTING_VIEW_HIDDEN) {
-                    continue;
+
+                if (configurator.GetUseLayerDebugMode()) {
+                    if (value.view == SETTING_VIEW_HIDDEN) {
+                        continue;
+                    }
+                } else {
+                    if (value.view != SETTING_VIEW_STANDARD) {
+                        continue;
+                    }
                 }
 
                 QTreeWidgetItem *child = new TreeItem(meta.key, value.key);
@@ -367,7 +389,17 @@ void SettingsTreeManager::BuildTreeItem(QTreeWidgetItem *parent, const SettingMe
 
                 WidgetSettingFlag *widget =
                     new WidgetSettingFlag(this->ui->configurations_settings, child, meta, parameter->settings, value.key);
-                this->connect(widget, SIGNAL(itemChanged()), this, SLOT(OnSettingChanged()));
+                this->connect(widget, SIGNAL(refreshEnableOnly()), this, SLOT(OnRefreshEnableOnly()));
+
+                if (value.status == STATUS_DEPRECATED && !value.deprecated_by_key.empty()) {
+                    const Layer *layer = configurator.layers.FindFromManifest(parameter->manifest);
+                    const SettingMeta *setting_meta = ::FindSetting(layer->settings, value.deprecated_by_key.c_str());
+                    child->setToolTip(
+                        0,
+                        format("Replaced by \"%s\" (%s) setting.", setting_meta->label.c_str(), setting_meta->key.c_str()).c_str());
+                } else {
+                    child->setToolTip(0, value.description.c_str());
+                }
 
                 for (std::size_t j = 0, o = value.settings.size(); j < o; ++j) {
                     this->BuildTreeItem(child, *value.settings[j]);
@@ -380,14 +412,15 @@ void SettingsTreeManager::BuildTreeItem(QTreeWidgetItem *parent, const SettingMe
 
             WidgetSettingString *widget =
                 new WidgetSettingString(this->ui->configurations_settings, item, meta, parameter->settings);
-            this->connect(widget, SIGNAL(itemChanged()), this, SLOT(OnSettingChanged()));
+            this->connect(widget, SIGNAL(refreshEnableOnly()), this, SLOT(OnRefreshEnableOnly()));
         } break;
 
         case SETTING_LIST: {
             const SettingMetaList &meta = static_cast<const SettingMetaList &>(meta_object);
 
             WidgetSettingList *widget = new WidgetSettingList(this->ui->configurations_settings, item, meta, parameter->settings);
-            this->connect(widget, SIGNAL(itemChanged()), this, SLOT(OnSettingChanged()));
+            this->connect(widget, SIGNAL(refreshEnableAndState()), this, SLOT(OnRefreshEnableAndState()));
+            this->connect(widget, SIGNAL(refreshEnableOnly()), this, SLOT(OnRefreshEnableOnly()));
         } break;
 
         default: {
@@ -396,6 +429,18 @@ void SettingsTreeManager::BuildTreeItem(QTreeWidgetItem *parent, const SettingMe
         } break;
     }
 
+    if (meta_object.status == STATUS_DEPRECATED) {
+        if (meta_object.deprecated_by_key.empty()) {
+            item->setToolTip(0, format("(%s) %s", GetToken(meta_object.status), meta_object.description.c_str()).c_str());
+        } else {
+            const Layer *layer = configurator.layers.FindFromManifest(parameter->manifest);
+            const SettingMeta *setting_meta = ::FindSetting(layer->settings, meta_object.deprecated_by_key.c_str());
+
+            item->setToolTip(
+                0, format("Replaced by \"%s\" (%s) setting.", setting_meta->label.c_str(), setting_meta->key.c_str()).c_str());
+        }
+    }
+
     for (std::size_t i = 0, n = meta_object.children.size(); i < n; ++i) {
         this->BuildTreeItem(item, *meta_object.children[i]);
     }
@@ -431,13 +476,19 @@ void SettingsTreeManager::OnLayerVersionChanged(int index) {
     assert(layer != nullptr);
     this->ui->configurations_versions->setToolTip(layer->manifest_path.AbsolutePath().c_str());
 
-    this->CreateGUI();
-
+    configurator.UpdateConfigurations();
     configurator.Override(OVERRIDE_AREA_ALL);
 
+    this->CreateGUI();
+
     emit signalLayerVersionChanged();
 }
 
+void SettingsTreeManager::OnSettingsResetted() {
+    // Reset default settings
+    this->ui->configurations_presets->setCurrentIndex(1);
+}
+
 void SettingsTreeManager::OnPresetChanged(int combox_preset_index) {
     const int preset_index = combox_preset_index - 1;
 
@@ -446,6 +497,7 @@ void SettingsTreeManager::OnPresetChanged(int combox_preset_index) {
     assert(parameter != nullptr);
 
     if (preset_index == Layer::NO_PRESET) {
+        this->ui->configurations_settings_reset->setEnabled(true);
         return;
     }
 
@@ -461,12 +513,26 @@ void SettingsTreeManager::OnPresetChanged(int combox_preset_index) {
     const LayerPreset &preset = layer->presets[preset_index];
     parameter->ApplyPresetSettings(preset);
 
+    configurator.Override(OVERRIDE_AREA_LAYERS_SETTINGS_BIT);
+
+    this->ui->configurations_settings_reset->setEnabled(preset_index != Layer::DEFAULT_PRESET);
     this->Refresh(REFRESH_ENABLE_AND_STATE);
 }
 
-void SettingsTreeManager::OnSettingChanged() {
+void SettingsTreeManager::OnRefreshEnableAndState() {
+    this->RefreshPresetLabel();
+    this->Refresh(REFRESH_ENABLE_AND_STATE);
+
+    Configurator &configurator = Configurator::Get();
+    configurator.Override(OVERRIDE_AREA_LAYERS_SETTINGS_BIT);
+}
+
+void SettingsTreeManager::OnRefreshEnableOnly() {
     this->RefreshPresetLabel();
     this->Refresh(REFRESH_ENABLE_ONLY);
+
+    Configurator &configurator = Configurator::Get();
+    configurator.Override(OVERRIDE_AREA_LAYERS_SETTINGS_BIT);
 }
 
 void SettingsTreeManager::RefreshPresetLabel() {
@@ -475,22 +541,11 @@ void SettingsTreeManager::RefreshPresetLabel() {
     const Layer *layer = configurator.layers.FindFromManifest(parameter->manifest);
 
     const int preset_index = layer->FindPresetIndex(parameter->settings) + 1;
+    this->ui->configurations_settings_reset->setEnabled(preset_index != Layer::DEFAULT_PRESET);
     this->ui->configurations_presets->setCurrentIndex(preset_index);
 }
 
-/*
-void SettingsTreeManager::RefreshVersion() {
-    if (this->layer_version != nullptr) {
-        this->layer_version->setEnabled(true);
-        QEvent resize_event(QEvent::Resize);
-        this->layer_version->eventFilter(nullptr, &resize_event);
-    }
-}
-*/
-
 void SettingsTreeManager::Refresh(RefreshAreas refresh_areas) {
-    Configurator &configurator = Configurator::Get();
-
     this->ui->configurations_settings->blockSignals(true);
 
     QTreeWidgetItem *root_item = this->ui->configurations_settings->invisibleRootItem();
@@ -499,16 +554,15 @@ void SettingsTreeManager::Refresh(RefreshAreas refresh_areas) {
     }
 
     this->ui->configurations_settings->blockSignals(false);
-
-    // Refresh layer configuration
-    configurator.Override(OVERRIDE_AREA_LAYERS_SETTINGS_BIT);
 }
 
 void SettingsTreeManager::RefreshItem(RefreshAreas refresh_areas, QTreeWidgetItem *parent) {
     QWidget *widget = this->ui->configurations_settings->itemWidget(parent, 0);
     if (widget != nullptr) {
         WidgetSettingBase *widget_base = dynamic_cast<WidgetSettingBase *>(widget);
-        if (widget_base != nullptr) widget_base->Refresh(refresh_areas);
+        if (widget_base != nullptr) {
+            widget_base->Refresh(refresh_areas);
+        }
     }
 
     for (int i = 0, n = parent->childCount(); i < n; ++i) {
